Preferences/ShortcutsDialog.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 53
c3eb7cc1ff8b
--- a/Preferences/ShortcutsDialog.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/Preferences/ShortcutsDialog.py	Sat Jan 02 17:09:08 2010 +0000
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog for the configuration of eric4s keyboard shortcuts.
+Module implementing a dialog for the configuration of eric5s keyboard shortcuts.
 """
 
 from PyQt4.QtCore import *
@@ -23,7 +23,7 @@
 
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
     Class implementing a dialog for the configuration of eric4s keyboard shortcuts.
     """
     objectNameRole = Qt.UserRole
     noCheckRole    = Qt.UserRole + 1
@@ -458,4 +458,4 @@
         @param checked state of the shortcuts radio button (boolean)
         """
         if checked:
-            self.on_searchEdit_textChanged(self.searchEdit.text())
+            self.on_searchEdit_textChanged(self.searchEdit.text())
\ No newline at end of file
@@ -23,7 +23,7 @@
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
-    Class implementing a dialog for the configuration of eric4s keyboard shortcuts.
+    Class implementing a dialog for the configuration of eric5s keyboard shortcuts.
     """
     objectNameRole = Qt.UserRole

eric ide

mercurial